(guide)=

# User Guide

The following pages walk through getting started with `smolgp`. For a hands-on introduction to the mathematical background behind state space Gaussian processes and specific topics and use-cases, head over to {ref}`tutorials`.

```{toctree}
:maxdepth: 1

install
citing
benchmarks
releasenotes
```
